Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TargetBuildConfig ¶
type TargetBuildConfig struct {
// Enable data race detection (supported only on amd64)
Race *bool `json:"race,omitempty"`
// List of build tags to consider satisfied during the build
Tags string `json:"tags,omitempty"`
// Arguments to pass on each go tool link invocation
LdFlags string `json:"ldflags,omitempty"`
// Indicates which kind of object file to build
Mode string `json:"mode,omitempty"`
// Whether to stamp binaries with version control information
VCS string `json:"vcs,omitempty"`
// Remove all file system paths from the resulting executable
TrimPath *bool `json:"trimpath,omitempty"`
// CGO dependency configure arguments
CrossArgs string `json:"cross_args,omitempty"`
}
type TargetConfig ¶
type TargetConfig struct {
TargetBuildConfig TargetBuildConfig
OutBinPath string
}
Click to show internal directories.
Click to hide internal directories.